@@ -43,6 +43,8 @@ def parse_args():
     parser.add_argument('-s', '--spell-check-off', dest='spell_check',
                         action='store_false',
                         help='disable spell-checking rules')
+    parser.add_argument('--ignore-comments', action='store_true',
+                        help='ignore lines that start with a hash')
     return parser.parse_args()
 
 
@@ -58,7 +60,8 @@ def get_rules(rules: str) -> set:
 
 def get_text(file, encoding):
     with open(file, encoding=encoding) as f:
-        text = ''.join(f.readlines())
+        text = ''.join(line for line in f.readlines()
+                       if not line.lstrip().startswith('#'))
     return text
 
 
@@ -122,15 +125,23 @@ def main():
                 if match.subId is not None:
                     rule_id += '[{}]'.format(match.subId)
 
-                replacement_text = ', '.join(match.replacements).strip()
-                print('{}:{}:{}: {}: {}{}'.format(
+                replacement_text = ', '.join(
+                    "'{}'".format(word)
+                    for word in match.replacements).strip()
+
+                message = match.msg
+
+                # Messages that end with punctuation already include the
+                # suggestion.
+                if replacement_text and not message.endswith(('.', '?')):
+                    message += '; suggestions: ' + replacement_text
+
+                print('{}:{}:{}: {}: {}'.format(
                     filename,
                     match.fromy + 1,
                     match.fromx + 1,
                     rule_id,
-                    match.msg,
-                    ('; suggestions: ' + replacement_text)
-                    if replacement_text else ''))
+                    message))
                 status = 2
 
     return status
